This folder is for Jupyter Notebooks that support the development process of
specific modules. They are for development of ORDeC, not the end user.

Please use the Jupytext format, not the ipynb format.
